import _object_spread from "@swc/helpers/src/_object_spread.mjs";
import _object_spread_props from "@swc/helpers/src/_object_spread_props.mjs";
import _object_without_properties from "@swc/helpers/src/_object_without_properties.mjs";
import { createElement, forwardRef } from 'react';
import cx from 'clsx';
import { responsive, createPrefixValueResolver } from '../utils';
import { resolveMargin } from '../utils/margin';
import { resolvePadding } from '../utils/padding';
import { resolveWidth, resolveHeight } from '../utils/dimension';
export const Box = /*#__PURE__*/ forwardRef((props, ref)=>{
    var ref1, ref2, ref3;
    const { element ='div' , className , margin , padding , width , height , background  } = props, rest = _object_without_properties(props, [
        "element",
        "className",
        "margin",
        "padding",
        "width",
        "height",
        "background"
    ]);
    const marginClassName = responsive(resolveMargin, margin);
    const paddingClassName = responsive(resolvePadding, padding);
    const widthClassName = responsive(resolveWidth, width);
    const heightClassName = responsive(resolveHeight, height);
    const backgroundAttachmentClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : background.attachment);
    const backgroundClipClassName = responsive(createPrefixValueResolver('bg-clip'), background === null || background === void 0 ? void 0 : background.clip);
    const backgroundColorClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : background.color);
    const backgroundOpacityClassName = responsive(createPrefixValueResolver('bg-opacity'), background === null || background === void 0 ? void 0 : background.opacity);
    const backgroundOriginClassName = responsive(createPrefixValueResolver('bg-origin'), background === null || background === void 0 ? void 0 : background.origin);
    const backgroundPositionClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : background.position);
    const backgroundRepeatClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : background.repeat);
    const backgroundSizeClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : background.size);
    const backgroundImageClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : background.image);
    const gradientFromClassName = responsive(createPrefixValueResolver('from'), background === null || background === void 0 ? void 0 : (ref1 = background.gradient) === null || ref1 === void 0 ? void 0 : ref1.from);
    const gradientViaClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : (ref2 = background.gradient) === null || ref2 === void 0 ? void 0 : ref2.via);
    const gradientToClassName = responsive(createPrefixValueResolver('bg'), background === null || background === void 0 ? void 0 : (ref3 = background.gradient) === null || ref3 === void 0 ? void 0 : ref3.to);
    return /*#__PURE__*/ createElement(element, _object_spread_props(_object_spread({
        className: cx(marginClassName, paddingClassName, widthClassName, heightClassName, backgroundAttachmentClassName, backgroundClipClassName, backgroundColorClassName, backgroundOpacityClassName, backgroundOriginClassName, backgroundPositionClassName, backgroundRepeatClassName, backgroundSizeClassName, backgroundImageClassName, gradientFromClassName, gradientViaClassName, gradientToClassName, className)
    }, rest), {
        ref
    }));
});

//# sourceMappingURL=Box.js.map