import _extends from "@swc/helpers/src/_extends.mjs";
import _object_without_properties from "@swc/helpers/src/_object_without_properties.mjs";
import cx from 'clsx';
import React from 'react';
import { responsive, resolveValue } from '../utils';
import { Box } from '../Box';
var Direction;
(function(Direction) {
    Direction["INSET"] = 'inset';
    Direction["Y"] = 'inset-y';
    Direction["X"] = 'inset-x';
    Direction["LEFT"] = 'left';
    Direction["RIGHT"] = 'right';
    Direction["TOP"] = 'top';
    Direction["BOTTOM"] = 'bottom';
})(Direction || (Direction = {}));
function PositionBase(props) {
    const { className , position , zIndex , inset , x , y , top , bottom , left , right  } = props, boxProps = _object_without_properties(props, [
        "className",
        "position",
        "zIndex",
        "inset",
        "x",
        "y",
        "top",
        "bottom",
        "left",
        "right"
    ]);
    // TODO: Support responsive
    const positionDirectionClassNames = resolveClassName({
        inset,
        x,
        y,
        top,
        bottom,
        left,
        right
    });
    return /*#__PURE__*/ React.createElement(Box, _extends({
        className: cx(responsive(resolveValue, position), positionDirectionClassNames, responsive(resolveValue, zIndex), className)
    }, boxProps));
}
export function Static(props) {
    return /*#__PURE__*/ React.createElement(PositionBase, _extends({
        position: "static"
    }, props));
}
export function Relative(props) {
    return /*#__PURE__*/ React.createElement(PositionBase, _extends({
        position: "relative"
    }, props));
}
export function Absolute(props) {
    return /*#__PURE__*/ React.createElement(PositionBase, _extends({
        position: "absolute"
    }, props));
}
export function Fixed(props) {
    return /*#__PURE__*/ React.createElement(PositionBase, _extends({
        position: "fixed"
    }, props));
}
export function Sticky(props) {
    return /*#__PURE__*/ React.createElement(PositionBase, _extends({
        position: "sticky"
    }, props));
}
function getClassName(dir, value) {
    if (value == null) return '';
    const isNegative = typeof value === 'number' && value < 0 || typeof value === 'string' && value[0] === '-';
    const normalizedValue = typeof value === 'number' ? Math.abs(value) : value.substring(1);
    const className = `${dir}-${normalizedValue}`;
    return isNegative ? `-${className}` : className;
}
function resolveClassName(direction) {
    if ('isnet' in direction) return getClassName(Direction.INSET, direction);
    // Always resolve to the most specific
    const top = 'y' in direction ? direction.y : direction.top;
    const bottom = 'y' in direction ? direction.y : direction.bottom;
    const left = 'x' in direction ? direction.x : direction.left;
    const right = 'x' in direction ? direction.x : direction.right;
    if (top === bottom && left === right && top === left) return getClassName(Direction.INSET, top);
    const classNames = [];
    if (top === bottom) classNames.push(getClassName(Direction.Y, top));
    else classNames.push(getClassName(Direction.TOP, top), getClassName(Direction.BOTTOM, bottom));
    if (left === right) classNames.push(getClassName(Direction.X, left));
    else classNames.push(getClassName(Direction.LEFT, left), getClassName(Direction.RIGHT, right));
    return cx(classNames);
}

//# sourceMappingURL=Position.js.map